Page 143 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 143

Home

    Christian books, and Christian tapes, than all the other
    countries put together, but South Africa produces more
    Bibles in more languages than any other country in the
    world.'®

    Peter Hammond also relates his eyewitness account
    of the Communist war against Christians in Africa:

    When I was first called up to do my military duty in
    the South African Defense Force, back in 1979, we came
    across atrocities in South West Africa and Angola.
    SWAPO, the South West African Peoples Organization,
    the terrorist group backed by the Soviets, and funded by
    the World Council of Churches, has been involved in war
    to try and overthrow Mozambique for the last 20 years.
    In that time they've killed 10,000 civilians, largely
    through land mines.

    We, as soldiers, had to sift through the wreckage of
    vehicles blown up by land mines, and we had to put the
    bodies into body bags. We had to sift through villages
    burned to the ground, and take the charred remains, the
    corpses of the people, and put them in body bags.

    When we were involved in operations in Angola, we
    used to seek out the churches in the villages. We would
    go into a village and say, "Where is the church?" and
    every time the people would point to a burnt out place
    and say, "That was the church. The Cubans burnt it
    down." We would say, "Where is the pastor?" and the
    people would say, "The Communists shot him.’ We
    would say, "What can we do to help you?" and the
    people would say, "Biblia, Biblia, — Bibles." Starving,
    hungry, thin people asked for Bibles as their first priority.

    138

    The Secret Side of History